import Vue from 'vue'
import VueRouter from 'vue-router'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css'
import store from './store'
import { pages } from './views'
import { checkAuthority } from './utils/authority';


Vue.use(VueRouter)

const routes = [
  {
    path: '/',
    name: 'index',
    redirect: '/dashboard',
    component: () => import('@/layout/index.vue'),
    children: [
      ...pages,
    ]
  },
  {
    path: '/login',
    name: 'login',
    component: () => import('@/views/Login.vue')
  },
  {
    path: '/exception',
    name: 'exception',
    component: () => import('@/layout/index.vue'),
    children: [
      {
        path: '404',
        name: 'notfound',
        component: () => import('@/views/NotFound.vue'),
      },
      {
        path: 'norights',
        name: 'norights',
        component: () => import('@/views/NoRights.vue'),
      },
    ]
  },
  {
    path: '*',
    redirect: { name: 'notfound' }
  }
]

const router = new VueRouter({ routes })

// 校验用户权限
router.beforeEach((to, from, next) => {
  NProgress.start()

  const toLogin = { name: 'login', query: { from: to.name } }
  const toIndex = { name: 'index' }
  const to403 = { name: 'norights' }

  // 尝试去获取人员
  store.dispatch('getUser').then(() => {
    // 校验权限
    if (checkAuthority(store.state, to.name)) {
      return to.name === 'login' || to.fullPath.indexOf('/exception') > -1 ? next(toIndex) : next()
    } else {
      return to.name === 'login' || to.fullPath.indexOf('/exception') > -1 ? next() : next(to403)
    }
  }).catch((err) => {
    window.console.error(err.message || err)
    return to.name === 'login' || to.fullPath.indexOf('/exception') > -1 ? next() : next(toLogin)
  })

})

router.afterEach(() => {
  NProgress.done()
})

export default router
