import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
    namespaced: true,
    state: {
        data: [],
        menus: [],
    },
    mutations: {
        setList(state, payload) {
            state.data = payload
        },
        setMenus(state, payload) {
            state.menus = payload
        }
    },
    actions: {
        getList({ commit }, payload) {
            return new Promise((resolve, reject) => {
                const api = apis.sysRole.list
                interact(api, payload).then((data) => {
                    commit('setList', data)
                    resolve(data)
                }).catch(()=>{
                    reject()
                })

            })
        },
        addRole( _, payload) {
            return new Promise((resolve, reject) => {
                const api = lodash.get(apis,'sysRole.save')
                interact(api, payload).then((data)=> {
                    resolve(data)
                }).catch(()=>{
                    reject()
                })
            })
        },
        getMenus({ commit }) {
            return new Promise((resolve, reject) => {
                const api = apis.menu.list
                interact(api).then((data) => {
                    resolve(data)
                    commit('setMenus', data)
                }).catch((err) => {
                    reject(err)
                })
            })
        },
        getById(_, payload) {
            return new Promise((resolve, reject) => {
                const api = apis.sysRole.get
                interact(replaceApiParams(api, { id: payload.roleId })).then((data) => {
                    resolve(data)
                }).catch(()=>{
                    reject()
                })
            })
        },
        updateRole(_, payload) {
            return new Promise((resolve, reject) => {
                const api = lodash.get(apis,'sysRole.update')
                interact(api, payload).then((data) => {
                    resolve(data)
                }).catch((err)=>{
                    reject(err)
                })
            })
        },
        deleteRole(_, role) {
            return new Promise((resolve, reject) => {
                const api = apis.sysRole.delete
                interact(replaceApiParams(api, { id: role.roleId })).then((data) => {
                    resolve(data)
                }).catch((err)=>{
                    reject(err)
                })
            })
        },
        aAddNode({ commit }) {
            return new Promise((resolve, reject) => {
                const api = lodash.get(apis, 'menu.add')
                interact(api).then((data) => {
                    resolve(data)
                    commit('setMenus', data)
                }).catch(() => {
                    reject()
                })
            })
        },
    }
}